# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _iqbalance_swig
else:
    import _iqbalance_swig

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)



def high_res_timer_now() -> "gr::high_res_timer_type":
    r"""high_res_timer_now() -> gr::high_res_timer_type"""
    return _iqbalance_swig.high_res_timer_now()

def high_res_timer_now_perfmon() -> "gr::high_res_timer_type":
    r"""high_res_timer_now_perfmon() -> gr::high_res_timer_type"""
    return _iqbalance_swig.high_res_timer_now_perfmon()

def high_res_timer_tps() -> "gr::high_res_timer_type":
    r"""high_res_timer_tps() -> gr::high_res_timer_type"""
    return _iqbalance_swig.high_res_timer_tps()

def high_res_timer_epoch() -> "gr::high_res_timer_type":
    r"""high_res_timer_epoch() -> gr::high_res_timer_type"""
    return _iqbalance_swig.high_res_timer_epoch()
class fix_cc(object):
    r"""Proxy of C++ gr::iqbalance::fix_cc class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def make(mag: "float"=0.0, phase: "float"=0.0) -> "gr::iqbalance::fix_cc::sptr":
        r"""make(float mag=0.0, float phase=0.0) -> fix_cc_sptr"""
        return _iqbalance_swig.fix_cc_make(mag, phase)
    __swig_destroy__ = _iqbalance_swig.delete_fix_cc

    def set_mag(self, mag: "float") -> "void":
        r"""set_mag(fix_cc self, float mag)"""
        return _iqbalance_swig.fix_cc_set_mag(self, mag)

    def set_phase(self, phase: "float") -> "void":
        r"""set_phase(fix_cc self, float phase)"""
        return _iqbalance_swig.fix_cc_set_phase(self, phase)

    def mag(self) -> "float":
        r"""mag(fix_cc self) -> float"""
        return _iqbalance_swig.fix_cc_mag(self)

    def phase(self) -> "float":
        r"""phase(fix_cc self) -> float"""
        return _iqbalance_swig.fix_cc_phase(self)

    def apply_new_corrections(self, msg: "swig_pmt_ptr") -> "void":
        r"""apply_new_corrections(fix_cc self, swig_pmt_ptr msg)"""
        return _iqbalance_swig.fix_cc_apply_new_corrections(self, msg)

    def work(self, noutput_items: "int", input_items: "gr_vector_const_void_star &", output_items: "gr_vector_void_star &") -> "int":
        r"""work(fix_cc self, int noutput_items, gr_vector_const_void_star & input_items, gr_vector_void_star & output_items) -> int"""
        return _iqbalance_swig.fix_cc_work(self, noutput_items, input_items, output_items)

# Register fix_cc in _iqbalance_swig:
_iqbalance_swig.fix_cc_swigregister(fix_cc)

def fix_cc_make(mag: "float"=0.0, phase: "float"=0.0) -> "gr::iqbalance::fix_cc::sptr":
    r"""fix_cc_make(float mag=0.0, float phase=0.0) -> fix_cc_sptr"""
    return _iqbalance_swig.fix_cc_make(mag, phase)

class fix_cc_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::iqbalance::fix_cc > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(fix_cc_sptr self) -> fix_cc_sptr
        __init__(fix_cc_sptr self, fix_cc p) -> fix_cc_sptr
        """
        _iqbalance_swig.fix_cc_sptr_swiginit(self, _iqbalance_swig.new_fix_cc_sptr(*args))

    def __deref__(self) -> "gr::iqbalance::fix_cc *":
        r"""__deref__(fix_cc_sptr self) -> fix_cc"""
        return _iqbalance_swig.fix_cc_sptr___deref__(self)
    __swig_destroy__ = _iqbalance_swig.delete_fix_cc_sptr

    def make(self, mag: "float"=0.0, phase: "float"=0.0) -> "gr::iqbalance::fix_cc::sptr":
        r"""make(fix_cc_sptr self, float mag=0.0, float phase=0.0) -> fix_cc_sptr"""
        return _iqbalance_swig.fix_cc_sptr_make(self, mag, phase)

    def set_mag(self, mag: "float") -> "void":
        r"""set_mag(fix_cc_sptr self, float mag)"""
        return _iqbalance_swig.fix_cc_sptr_set_mag(self, mag)

    def set_phase(self, phase: "float") -> "void":
        r"""set_phase(fix_cc_sptr self, float phase)"""
        return _iqbalance_swig.fix_cc_sptr_set_phase(self, phase)

    def mag(self) -> "float":
        r"""mag(fix_cc_sptr self) -> float"""
        return _iqbalance_swig.fix_cc_sptr_mag(self)

    def phase(self) -> "float":
        r"""phase(fix_cc_sptr self) -> float"""
        return _iqbalance_swig.fix_cc_sptr_phase(self)

    def apply_new_corrections(self, msg: "swig_pmt_ptr") -> "void":
        r"""apply_new_corrections(fix_cc_sptr self, swig_pmt_ptr msg)"""
        return _iqbalance_swig.fix_cc_sptr_apply_new_corrections(self, msg)

    def work(self, noutput_items: "int", input_items: "gr_vector_const_void_star &", output_items: "gr_vector_void_star &") -> "int":
        r"""work(fix_cc_sptr self, int noutput_items, gr_vector_const_void_star & input_items, gr_vector_void_star & output_items) -> int"""
        return _iqbalance_swig.fix_cc_sptr_work(self, noutput_items, input_items, output_items)

    def history(self) -> "unsigned int":
        r"""history(fix_cc_sptr self) -> unsigned int"""
        return _iqbalance_swig.fix_cc_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(fix_cc_sptr self, int which, int delay)
        declare_sample_delay(fix_cc_sptr self, unsigned int delay)
        """
        return _iqbalance_swig.fix_cc_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(fix_cc_sptr self, int which) -> unsigned int"""
        return _iqbalance_swig.fix_cc_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(fix_cc_sptr self, int multiple)"""
        return _iqbalance_swig.fix_cc_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(fix_cc_sptr self) -> int"""
        return _iqbalance_swig.fix_cc_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(fix_cc_sptr self) -> double"""
        return _iqbalance_swig.fix_cc_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(fix_cc_sptr self) -> uint64_t"""
        return _iqbalance_swig.fix_cc_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(fix_cc_sptr self) -> uint64_t"""
        return _iqbalance_swig.fix_cc_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(fix_cc_sptr self) -> bool"""
        return _iqbalance_swig.fix_cc_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(fix_cc_sptr self) -> bool"""
        return _iqbalance_swig.fix_cc_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(fix_cc_sptr self, unsigned int which_input) -> uint64_t"""
        return _iqbalance_swig.fix_cc_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(fix_cc_sptr self, unsigned int which_output) -> uint64_t"""
        return _iqbalance_swig.fix_cc_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(fix_cc_sptr self, std::string level)"""
        return _iqbalance_swig.fix_cc_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(fix_cc_sptr self) -> std::string"""
        return _iqbalance_swig.fix_cc_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(fix_cc_sptr self) -> int"""
        return _iqbalance_swig.fix_cc_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(fix_cc_sptr self, int m)"""
        return _iqbalance_swig.fix_cc_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(fix_cc_sptr self)"""
        return _iqbalance_swig.fix_cc_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(fix_cc_sptr self) -> bool"""
        return _iqbalance_swig.fix_cc_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(fix_cc_sptr self, int m)"""
        return _iqbalance_swig.fix_cc_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(fix_cc_sptr self) -> int"""
        return _iqbalance_swig.fix_cc_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(fix_cc_sptr self, int i) -> long"""
        return _iqbalance_swig.fix_cc_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(fix_cc_sptr self, long max_output_buffer)
        set_max_output_buffer(fix_cc_sptr self, int port, long max_output_buffer)
        """
        return _iqbalance_swig.fix_cc_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(fix_cc_sptr self, int i) -> long"""
        return _iqbalance_swig.fix_cc_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(fix_cc_sptr self, long min_output_buffer)
        set_min_output_buffer(fix_cc_sptr self, int port, long min_output_buffer)
        """
        return _iqbalance_swig.fix_cc_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(fix_cc_sptr self) -> float"""
        return _iqbalance_swig.fix_cc_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(fix_cc_sptr self) -> float"""
        return _iqbalance_swig.fix_cc_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(fix_cc_sptr self) -> float"""
        return _iqbalance_swig.fix_cc_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(fix_cc_sptr self) -> float"""
        return _iqbalance_swig.fix_cc_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(fix_cc_sptr self) -> float"""
        return _iqbalance_swig.fix_cc_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(fix_cc_sptr self) -> float"""
        return _iqbalance_swig.fix_cc_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(fix_cc_sptr self, int which) -> float
        pc_input_buffers_full(fix_cc_sptr self) -> pmt_vector_float
        """
        return _iqbalance_swig.fix_cc_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(fix_cc_sptr self, int which) -> float
        pc_input_buffers_full_avg(fix_cc_sptr self) -> pmt_vector_float
        """
        return _iqbalance_swig.fix_cc_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(fix_cc_sptr self, int which) -> float
        pc_input_buffers_full_var(fix_cc_sptr self) -> pmt_vector_float
        """
        return _iqbalance_swig.fix_cc_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(fix_cc_sptr self, int which) -> float
        pc_output_buffers_full(fix_cc_sptr self) -> pmt_vector_float
        """
        return _iqbalance_swig.fix_cc_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(fix_cc_sptr self, int which) -> float
        pc_output_buffers_full_avg(fix_cc_sptr self) -> pmt_vector_float
        """
        return _iqbalance_swig.fix_cc_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(fix_cc_sptr self, int which) -> float
        pc_output_buffers_full_var(fix_cc_sptr self) -> pmt_vector_float
        """
        return _iqbalance_swig.fix_cc_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(fix_cc_sptr self) -> float"""
        return _iqbalance_swig.fix_cc_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(fix_cc_sptr self) -> float"""
        return _iqbalance_swig.fix_cc_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(fix_cc_sptr self) -> float"""
        return _iqbalance_swig.fix_cc_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(fix_cc_sptr self) -> float"""
        return _iqbalance_swig.fix_cc_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(fix_cc_sptr self) -> float"""
        return _iqbalance_swig.fix_cc_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(fix_cc_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _iqbalance_swig.fix_cc_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(fix_cc_sptr self)"""
        return _iqbalance_swig.fix_cc_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(fix_cc_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _iqbalance_swig.fix_cc_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(fix_cc_sptr self) -> int"""
        return _iqbalance_swig.fix_cc_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(fix_cc_sptr self) -> int"""
        return _iqbalance_swig.fix_cc_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(fix_cc_sptr self, int priority) -> int"""
        return _iqbalance_swig.fix_cc_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(fix_cc_sptr self) -> std::string"""
        return _iqbalance_swig.fix_cc_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(fix_cc_sptr self) -> std::string"""
        return _iqbalance_swig.fix_cc_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(fix_cc_sptr self) -> io_signature_sptr"""
        return _iqbalance_swig.fix_cc_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(fix_cc_sptr self) -> io_signature_sptr"""
        return _iqbalance_swig.fix_cc_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(fix_cc_sptr self) -> long"""
        return _iqbalance_swig.fix_cc_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(fix_cc_sptr self) -> basic_block_sptr"""
        return _iqbalance_swig.fix_cc_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(fix_cc_sptr self, int ninputs, int noutputs) -> bool"""
        return _iqbalance_swig.fix_cc_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(fix_cc_sptr self) -> std::string"""
        return _iqbalance_swig.fix_cc_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(fix_cc_sptr self, std::string name)"""
        return _iqbalance_swig.fix_cc_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(fix_cc_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _iqbalance_swig.fix_cc_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(fix_cc_sptr self) -> swig_pmt_ptr"""
        return _iqbalance_swig.fix_cc_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(fix_cc_sptr self) -> swig_pmt_ptr"""
        return _iqbalance_swig.fix_cc_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(fix_cc_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _iqbalance_swig.fix_cc_sptr_message_subscribers(self, which_port)

# Register fix_cc_sptr in _iqbalance_swig:
_iqbalance_swig.fix_cc_sptr_swigregister(fix_cc_sptr)


fix_cc_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
fix_cc = fix_cc.make;

class optimize_c(object):
    r"""Proxy of C++ gr::iqbalance::optimize_c class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def make(period: "int"=0) -> "gr::iqbalance::optimize_c::sptr":
        r"""make(int period=0) -> optimize_c_sptr"""
        return _iqbalance_swig.optimize_c_make(period)
    __swig_destroy__ = _iqbalance_swig.delete_optimize_c

    def set_period(self, period: "int") -> "void":
        r"""set_period(optimize_c self, int period)"""
        return _iqbalance_swig.optimize_c_set_period(self, period)

    def period(self) -> "int":
        r"""period(optimize_c self) -> int"""
        return _iqbalance_swig.optimize_c_period(self)

    def mag(self) -> "float":
        r"""mag(optimize_c self) -> float"""
        return _iqbalance_swig.optimize_c_mag(self)

    def phase(self) -> "float":
        r"""phase(optimize_c self) -> float"""
        return _iqbalance_swig.optimize_c_phase(self)

    def reset(self) -> "void":
        r"""reset(optimize_c self)"""
        return _iqbalance_swig.optimize_c_reset(self)

    def forecast(self, noutput_items: "int", ninput_items_required: "gr_vector_int &") -> "void":
        r"""forecast(optimize_c self, int noutput_items, gr_vector_int & ninput_items_required)"""
        return _iqbalance_swig.optimize_c_forecast(self, noutput_items, ninput_items_required)

    def work(self, noutput_items: "int", input_items: "gr_vector_const_void_star &", output_items: "gr_vector_void_star &") -> "int":
        r"""work(optimize_c self, int noutput_items, gr_vector_const_void_star & input_items, gr_vector_void_star & output_items) -> int"""
        return _iqbalance_swig.optimize_c_work(self, noutput_items, input_items, output_items)

# Register optimize_c in _iqbalance_swig:
_iqbalance_swig.optimize_c_swigregister(optimize_c)

def optimize_c_make(period: "int"=0) -> "gr::iqbalance::optimize_c::sptr":
    r"""optimize_c_make(int period=0) -> optimize_c_sptr"""
    return _iqbalance_swig.optimize_c_make(period)

class optimize_c_sptr(object):
    r"""Proxy of C++ boost::shared_ptr< gr::iqbalance::optimize_c > class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        __init__(optimize_c_sptr self) -> optimize_c_sptr
        __init__(optimize_c_sptr self, optimize_c p) -> optimize_c_sptr
        """
        _iqbalance_swig.optimize_c_sptr_swiginit(self, _iqbalance_swig.new_optimize_c_sptr(*args))

    def __deref__(self) -> "gr::iqbalance::optimize_c *":
        r"""__deref__(optimize_c_sptr self) -> optimize_c"""
        return _iqbalance_swig.optimize_c_sptr___deref__(self)
    __swig_destroy__ = _iqbalance_swig.delete_optimize_c_sptr

    def make(self, period: "int"=0) -> "gr::iqbalance::optimize_c::sptr":
        r"""make(optimize_c_sptr self, int period=0) -> optimize_c_sptr"""
        return _iqbalance_swig.optimize_c_sptr_make(self, period)

    def set_period(self, period: "int") -> "void":
        r"""set_period(optimize_c_sptr self, int period)"""
        return _iqbalance_swig.optimize_c_sptr_set_period(self, period)

    def period(self) -> "int":
        r"""period(optimize_c_sptr self) -> int"""
        return _iqbalance_swig.optimize_c_sptr_period(self)

    def mag(self) -> "float":
        r"""mag(optimize_c_sptr self) -> float"""
        return _iqbalance_swig.optimize_c_sptr_mag(self)

    def phase(self) -> "float":
        r"""phase(optimize_c_sptr self) -> float"""
        return _iqbalance_swig.optimize_c_sptr_phase(self)

    def reset(self) -> "void":
        r"""reset(optimize_c_sptr self)"""
        return _iqbalance_swig.optimize_c_sptr_reset(self)

    def forecast(self, noutput_items: "int", ninput_items_required: "gr_vector_int &") -> "void":
        r"""forecast(optimize_c_sptr self, int noutput_items, gr_vector_int & ninput_items_required)"""
        return _iqbalance_swig.optimize_c_sptr_forecast(self, noutput_items, ninput_items_required)

    def work(self, noutput_items: "int", input_items: "gr_vector_const_void_star &", output_items: "gr_vector_void_star &") -> "int":
        r"""work(optimize_c_sptr self, int noutput_items, gr_vector_const_void_star & input_items, gr_vector_void_star & output_items) -> int"""
        return _iqbalance_swig.optimize_c_sptr_work(self, noutput_items, input_items, output_items)

    def history(self) -> "unsigned int":
        r"""history(optimize_c_sptr self) -> unsigned int"""
        return _iqbalance_swig.optimize_c_sptr_history(self)

    def declare_sample_delay(self, *args) -> "void":
        r"""
        declare_sample_delay(optimize_c_sptr self, int which, int delay)
        declare_sample_delay(optimize_c_sptr self, unsigned int delay)
        """
        return _iqbalance_swig.optimize_c_sptr_declare_sample_delay(self, *args)

    def sample_delay(self, which: "int") -> "unsigned int":
        r"""sample_delay(optimize_c_sptr self, int which) -> unsigned int"""
        return _iqbalance_swig.optimize_c_sptr_sample_delay(self, which)

    def set_output_multiple(self, multiple: "int") -> "void":
        r"""set_output_multiple(optimize_c_sptr self, int multiple)"""
        return _iqbalance_swig.optimize_c_sptr_set_output_multiple(self, multiple)

    def output_multiple(self) -> "int":
        r"""output_multiple(optimize_c_sptr self) -> int"""
        return _iqbalance_swig.optimize_c_sptr_output_multiple(self)

    def relative_rate(self) -> "double":
        r"""relative_rate(optimize_c_sptr self) -> double"""
        return _iqbalance_swig.optimize_c_sptr_relative_rate(self)

    def relative_rate_i(self) -> "uint64_t":
        r"""relative_rate_i(optimize_c_sptr self) -> uint64_t"""
        return _iqbalance_swig.optimize_c_sptr_relative_rate_i(self)

    def relative_rate_d(self) -> "uint64_t":
        r"""relative_rate_d(optimize_c_sptr self) -> uint64_t"""
        return _iqbalance_swig.optimize_c_sptr_relative_rate_d(self)

    def start(self) -> "bool":
        r"""start(optimize_c_sptr self) -> bool"""
        return _iqbalance_swig.optimize_c_sptr_start(self)

    def stop(self) -> "bool":
        r"""stop(optimize_c_sptr self) -> bool"""
        return _iqbalance_swig.optimize_c_sptr_stop(self)

    def nitems_read(self, which_input: "unsigned int") -> "uint64_t":
        r"""nitems_read(optimize_c_sptr self, unsigned int which_input) -> uint64_t"""
        return _iqbalance_swig.optimize_c_sptr_nitems_read(self, which_input)

    def nitems_written(self, which_output: "unsigned int") -> "uint64_t":
        r"""nitems_written(optimize_c_sptr self, unsigned int which_output) -> uint64_t"""
        return _iqbalance_swig.optimize_c_sptr_nitems_written(self, which_output)

    def set_log_level(self, level: "std::string") -> "void":
        r"""set_log_level(optimize_c_sptr self, std::string level)"""
        return _iqbalance_swig.optimize_c_sptr_set_log_level(self, level)

    def log_level(self) -> "std::string":
        r"""log_level(optimize_c_sptr self) -> std::string"""
        return _iqbalance_swig.optimize_c_sptr_log_level(self)

    def max_noutput_items(self) -> "int":
        r"""max_noutput_items(optimize_c_sptr self) -> int"""
        return _iqbalance_swig.optimize_c_sptr_max_noutput_items(self)

    def set_max_noutput_items(self, m: "int") -> "void":
        r"""set_max_noutput_items(optimize_c_sptr self, int m)"""
        return _iqbalance_swig.optimize_c_sptr_set_max_noutput_items(self, m)

    def unset_max_noutput_items(self) -> "void":
        r"""unset_max_noutput_items(optimize_c_sptr self)"""
        return _iqbalance_swig.optimize_c_sptr_unset_max_noutput_items(self)

    def is_set_max_noutput_items(self) -> "bool":
        r"""is_set_max_noutput_items(optimize_c_sptr self) -> bool"""
        return _iqbalance_swig.optimize_c_sptr_is_set_max_noutput_items(self)

    def set_min_noutput_items(self, m: "int") -> "void":
        r"""set_min_noutput_items(optimize_c_sptr self, int m)"""
        return _iqbalance_swig.optimize_c_sptr_set_min_noutput_items(self, m)

    def min_noutput_items(self) -> "int":
        r"""min_noutput_items(optimize_c_sptr self) -> int"""
        return _iqbalance_swig.optimize_c_sptr_min_noutput_items(self)

    def max_output_buffer(self, i: "int") -> "long":
        r"""max_output_buffer(optimize_c_sptr self, int i) -> long"""
        return _iqbalance_swig.optimize_c_sptr_max_output_buffer(self, i)

    def set_max_output_buffer(self, *args) -> "void":
        r"""
        set_max_output_buffer(optimize_c_sptr self, long max_output_buffer)
        set_max_output_buffer(optimize_c_sptr self, int port, long max_output_buffer)
        """
        return _iqbalance_swig.optimize_c_sptr_set_max_output_buffer(self, *args)

    def min_output_buffer(self, i: "int") -> "long":
        r"""min_output_buffer(optimize_c_sptr self, int i) -> long"""
        return _iqbalance_swig.optimize_c_sptr_min_output_buffer(self, i)

    def set_min_output_buffer(self, *args) -> "void":
        r"""
        set_min_output_buffer(optimize_c_sptr self, long min_output_buffer)
        set_min_output_buffer(optimize_c_sptr self, int port, long min_output_buffer)
        """
        return _iqbalance_swig.optimize_c_sptr_set_min_output_buffer(self, *args)

    def pc_noutput_items(self) -> "float":
        r"""pc_noutput_items(optimize_c_sptr self) -> float"""
        return _iqbalance_swig.optimize_c_sptr_pc_noutput_items(self)

    def pc_noutput_items_avg(self) -> "float":
        r"""pc_noutput_items_avg(optimize_c_sptr self) -> float"""
        return _iqbalance_swig.optimize_c_sptr_pc_noutput_items_avg(self)

    def pc_noutput_items_var(self) -> "float":
        r"""pc_noutput_items_var(optimize_c_sptr self) -> float"""
        return _iqbalance_swig.optimize_c_sptr_pc_noutput_items_var(self)

    def pc_nproduced(self) -> "float":
        r"""pc_nproduced(optimize_c_sptr self) -> float"""
        return _iqbalance_swig.optimize_c_sptr_pc_nproduced(self)

    def pc_nproduced_avg(self) -> "float":
        r"""pc_nproduced_avg(optimize_c_sptr self) -> float"""
        return _iqbalance_swig.optimize_c_sptr_pc_nproduced_avg(self)

    def pc_nproduced_var(self) -> "float":
        r"""pc_nproduced_var(optimize_c_sptr self) -> float"""
        return _iqbalance_swig.optimize_c_sptr_pc_nproduced_var(self)

    def pc_input_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full(optimize_c_sptr self, int which) -> float
        pc_input_buffers_full(optimize_c_sptr self) -> pmt_vector_float
        """
        return _iqbalance_swig.optimize_c_sptr_pc_input_buffers_full(self, *args)

    def pc_input_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_avg(optimize_c_sptr self, int which) -> float
        pc_input_buffers_full_avg(optimize_c_sptr self) -> pmt_vector_float
        """
        return _iqbalance_swig.optimize_c_sptr_pc_input_buffers_full_avg(self, *args)

    def pc_input_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_input_buffers_full_var(optimize_c_sptr self, int which) -> float
        pc_input_buffers_full_var(optimize_c_sptr self) -> pmt_vector_float
        """
        return _iqbalance_swig.optimize_c_sptr_pc_input_buffers_full_var(self, *args)

    def pc_output_buffers_full(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full(optimize_c_sptr self, int which) -> float
        pc_output_buffers_full(optimize_c_sptr self) -> pmt_vector_float
        """
        return _iqbalance_swig.optimize_c_sptr_pc_output_buffers_full(self, *args)

    def pc_output_buffers_full_avg(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_avg(optimize_c_sptr self, int which) -> float
        pc_output_buffers_full_avg(optimize_c_sptr self) -> pmt_vector_float
        """
        return _iqbalance_swig.optimize_c_sptr_pc_output_buffers_full_avg(self, *args)

    def pc_output_buffers_full_var(self, *args) -> "std::vector< float,std::allocator< float > >":
        r"""
        pc_output_buffers_full_var(optimize_c_sptr self, int which) -> float
        pc_output_buffers_full_var(optimize_c_sptr self) -> pmt_vector_float
        """
        return _iqbalance_swig.optimize_c_sptr_pc_output_buffers_full_var(self, *args)

    def pc_work_time(self) -> "float":
        r"""pc_work_time(optimize_c_sptr self) -> float"""
        return _iqbalance_swig.optimize_c_sptr_pc_work_time(self)

    def pc_work_time_avg(self) -> "float":
        r"""pc_work_time_avg(optimize_c_sptr self) -> float"""
        return _iqbalance_swig.optimize_c_sptr_pc_work_time_avg(self)

    def pc_work_time_var(self) -> "float":
        r"""pc_work_time_var(optimize_c_sptr self) -> float"""
        return _iqbalance_swig.optimize_c_sptr_pc_work_time_var(self)

    def pc_work_time_total(self) -> "float":
        r"""pc_work_time_total(optimize_c_sptr self) -> float"""
        return _iqbalance_swig.optimize_c_sptr_pc_work_time_total(self)

    def pc_throughput_avg(self) -> "float":
        r"""pc_throughput_avg(optimize_c_sptr self) -> float"""
        return _iqbalance_swig.optimize_c_sptr_pc_throughput_avg(self)

    def set_processor_affinity(self, mask: "std::vector< int,std::allocator< int > > const &") -> "void":
        r"""set_processor_affinity(optimize_c_sptr self, std::vector< int,std::allocator< int > > const & mask)"""
        return _iqbalance_swig.optimize_c_sptr_set_processor_affinity(self, mask)

    def unset_processor_affinity(self) -> "void":
        r"""unset_processor_affinity(optimize_c_sptr self)"""
        return _iqbalance_swig.optimize_c_sptr_unset_processor_affinity(self)

    def processor_affinity(self) -> "std::vector< int,std::allocator< int > >":
        r"""processor_affinity(optimize_c_sptr self) -> std::vector< int,std::allocator< int > >"""
        return _iqbalance_swig.optimize_c_sptr_processor_affinity(self)

    def active_thread_priority(self) -> "int":
        r"""active_thread_priority(optimize_c_sptr self) -> int"""
        return _iqbalance_swig.optimize_c_sptr_active_thread_priority(self)

    def thread_priority(self) -> "int":
        r"""thread_priority(optimize_c_sptr self) -> int"""
        return _iqbalance_swig.optimize_c_sptr_thread_priority(self)

    def set_thread_priority(self, priority: "int") -> "int":
        r"""set_thread_priority(optimize_c_sptr self, int priority) -> int"""
        return _iqbalance_swig.optimize_c_sptr_set_thread_priority(self, priority)

    def name(self) -> "std::string":
        r"""name(optimize_c_sptr self) -> std::string"""
        return _iqbalance_swig.optimize_c_sptr_name(self)

    def symbol_name(self) -> "std::string":
        r"""symbol_name(optimize_c_sptr self) -> std::string"""
        return _iqbalance_swig.optimize_c_sptr_symbol_name(self)

    def input_signature(self) -> "gr::io_signature::sptr":
        r"""input_signature(optimize_c_sptr self) -> io_signature_sptr"""
        return _iqbalance_swig.optimize_c_sptr_input_signature(self)

    def output_signature(self) -> "gr::io_signature::sptr":
        r"""output_signature(optimize_c_sptr self) -> io_signature_sptr"""
        return _iqbalance_swig.optimize_c_sptr_output_signature(self)

    def unique_id(self) -> "long":
        r"""unique_id(optimize_c_sptr self) -> long"""
        return _iqbalance_swig.optimize_c_sptr_unique_id(self)

    def to_basic_block(self) -> "gr::basic_block_sptr":
        r"""to_basic_block(optimize_c_sptr self) -> basic_block_sptr"""
        return _iqbalance_swig.optimize_c_sptr_to_basic_block(self)

    def check_topology(self, ninputs: "int", noutputs: "int") -> "bool":
        r"""check_topology(optimize_c_sptr self, int ninputs, int noutputs) -> bool"""
        return _iqbalance_swig.optimize_c_sptr_check_topology(self, ninputs, noutputs)

    def alias(self) -> "std::string":
        r"""alias(optimize_c_sptr self) -> std::string"""
        return _iqbalance_swig.optimize_c_sptr_alias(self)

    def set_block_alias(self, name: "std::string") -> "void":
        r"""set_block_alias(optimize_c_sptr self, std::string name)"""
        return _iqbalance_swig.optimize_c_sptr_set_block_alias(self, name)

    def _post(self, which_port: "swig_pmt_ptr", msg: "swig_pmt_ptr") -> "void":
        r"""_post(optimize_c_sptr self, swig_pmt_ptr which_port, swig_pmt_ptr msg)"""
        return _iqbalance_swig.optimize_c_sptr__post(self, which_port, msg)

    def message_ports_in(self) -> "pmt::pmt_t":
        r"""message_ports_in(optimize_c_sptr self) -> swig_pmt_ptr"""
        return _iqbalance_swig.optimize_c_sptr_message_ports_in(self)

    def message_ports_out(self) -> "pmt::pmt_t":
        r"""message_ports_out(optimize_c_sptr self) -> swig_pmt_ptr"""
        return _iqbalance_swig.optimize_c_sptr_message_ports_out(self)

    def message_subscribers(self, which_port: "swig_pmt_ptr") -> "pmt::pmt_t":
        r"""message_subscribers(optimize_c_sptr self, swig_pmt_ptr which_port) -> swig_pmt_ptr"""
        return _iqbalance_swig.optimize_c_sptr_message_subscribers(self, which_port)

# Register optimize_c_sptr in _iqbalance_swig:
_iqbalance_swig.optimize_c_sptr_swigregister(optimize_c_sptr)


optimize_c_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id())
optimize_c = optimize_c.make;



